﻿using System;
using System.ComponentModel;
using System.Windows.Forms;

using TestClient.SimpleService;

namespace TestClient
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 클라이언트
        /// </summary>
        private SimpleServiceClient client;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.client = new SimpleServiceClient("NetTcpBinding_ISimpleService");

            this.getEvenNumberListButton.Click += getEvenNumberListButton_Click;
            this.getOddNumberListButton.Click  += getOddNumberListButton_Click;
            this.clearResultButton.Click       += clearResultButton_Click;

            this.oddNumberBackgroundWorker.DoWork              += oddNumberBackgroundWorker_DoWork;
            this.oddNumberBackgroundWorker.RunWorkerCompleted  += oddNumberBackgroundWorker_RunWorkerCompleted;
            this.evenNumberBackgroundWorker.DoWork             += evenNumberBackgroundWorker_DoWork;
            this.evenNumberBackgroundWorker.RunWorkerCompleted += evenNumberBackgroundWorker_RunWorkerCompleted;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 짝수 번호 리스트 구하기 버튼 클릭시 처리하기 - getEvenNumberListButton_Click(sender, e)

        /// <summary>
        /// 짝수 번호 리스트 구하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void getEvenNumberListButton_Click(object sender, EventArgs e)
        {
            this.evenNumberBackgroundWorker.RunWorkerAsync();
        }

        #endregion
        #region 홀수 번호 리스트 구하기 버튼 클릭시 처리하기 - getOddNumberListButton_Click(sender, e)

        /// <summary>
        /// 홀수 번호 리스트 구하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void getOddNumberListButton_Click(object sender, EventArgs e)
        {
            this.oddNumberBackgroundWorker.RunWorkerAsync();
        }

        #endregion
        #region 결과 지우기 버튼 클릭시 처리하기 - clearResultButton_Click(sender, e)

        /// <summary>
        /// 결과 지우기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void clearResultButton_Click(object sender, EventArgs e)
        {
            this.evenNumberListBox.DataSource = null;
            this.oddNumberListBox.DataSource = null;
        }

        #endregion

        #region 짝수 번호 백그라운드 작업자 작업 처리하기 - evenNumberBackgroundWorker_DoWork(sender, e)

        /// <summary>
        /// 짝수 번호 백그라운드 작업자 작업 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void evenNumberBackgroundWorker_DoWork(object sender, DoWorkEventArgs e)
        {
            e.Result = this.client.GetEvenNumberList();
        }

        #endregion
        #region 짝수 번호 백그라운드 작업자 작업 완료시 처리하기 - evenNumberBackgroundWorker_RunWorkerCompleted(sender, e)

        /// <summary>
        /// 짝수 번호 백그라운드 작업자 작업 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void evenNumberBackgroundWorker_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {
            this.evenNumberListBox.DataSource = (int[])e.Result;
        }

        #endregion
        #region 홀수 번호 백그라운드 작업자 작업 처리하기 - oddNumberBackgroundWorker_DoWork(sender, e)

        /// <summary>
        /// 홀수 번호 백그라운드 작업자 작업 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void oddNumberBackgroundWorker_DoWork(object sender, DoWorkEventArgs e)
        {
            e.Result = this.client.GetOddNumberList();
        }

        #endregion
        #region 홀수 번호 백그라운드 작업자 작업 완료시 처리하기 - oddNumberBackgroundWorker_RunWorkerCompleted(sender, e)

        /// <summary>
        /// 홀수 번호 백그라운드 작업자 작업 완료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void oddNumberBackgroundWorker_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {
            this.oddNumberListBox.DataSource = (int[])e.Result;
        }

        #endregion
    }
}